fn replace_stdio_fd(this: BorrowedFd<'_>, other: OwnedFd) -> Result<()>Expand description
Replaces the underlying file descriptor with the one from other.
Does not set CLOEXEC.
fn replace_stdio_fd(this: BorrowedFd<'_>, other: OwnedFd) -> Result<()>Replaces the underlying file descriptor with the one from other.
Does not set CLOEXEC.